<?php
/**
 * Plugin Name:     Dealia
 * Plugin URI:      PLUGIN SITE HERE
 * Description:     Add REQUEST A QUOTE button to your content pages and product pages. Create custom RFQ forms. Negotiate prices with your customers and complete transactions all in one place
 * Author:          dealia.com
 * Author URI:      https://dealia.com
 * Text Domain:     dealia
 * Domain Path:     /languages
 * Version:         0.1.0
 *
 * @package         Dealia
 */

// Your code starts here.


require_once(WP_PLUGIN_DIR . "/dealia/lib/DealiaConnector.php");

function dealia_settings_init() {


    add_action('admin_head', 'dealia_loadCss');

    
	register_setting('dealia', 'dealia_options', [
        'type'              => 'array',
        'sanitize_callback' => 'dealia_sanitize_options',
    ]);

	add_settings_section(
		'dealia_section_connetct',
		__( 'Connect your Dealia account.', 'dealia' ), 'dealia_section_connetct_callback',
		'dealia'
	);

	add_settings_field(
		'dealia_field_email', 		                        
		__( 'Email address', 'dealia' ),
		'dealia_field_email',
		'dealia',
		'dealia_section_connetct',
		array(
			'label_for'         => 'dealia_field_email',
			'class'             => 'dealia_row',
		)
	);    

	add_settings_field(
		'dealia_field_password', 		                        
		__( 'password', 'dealia' ),
		'dealia_field_password',
		'dealia',
		'dealia_section_connetct',
		array(
			'label_for'         => 'dealia_field_password',
			'class'             => 'dealia_row',
		)
	);    

    
    add_option('dealia_integration_code', '');

}


add_action( 'admin_init', 'dealia_settings_init' );

function dealia_section_connetct_callback( $args ) {

    if(DealiaConnector::getAccessToken() == null) {
	?>
	<p id="<?php echo esc_attr( $args['id'] ); ?>"><?php echo 'In order to use this plugin you must connect your Dealia.com account. If you don\'t have Dealia.com account yet please <a href="https://dealia.com/register" target="_blank">register now</a>.'; ?></p>
	<?php
    }
    else {
        $dealiaOptions = get_option( 'dealia_options' );
        ?>
        <p id="<?php echo esc_attr( $args['id'] ); ?>">Your account is connected &nbsp;&nbsp; <a target="_blank" href="https://dealia.com/login?email=<?php echo urlencode($dealiaOptions['dealia_field_email']); ?>&password=<?php echo urlencode($dealiaOptions['dealia_field_password']) ?>">Open my Dealia.com account</a>
        <?php
    }
}


function dealia_field_email( $args ) {
	$options = get_option( 'dealia_options' );
	?>
    <input type="text" autocomplete="off" autofill="off" name="dealia_options[<?php echo esc_attr( $args['label_for'] ); ?>]" value="<?php if($options && $options[ $args['label_for'] ]) { echo  $options[ $args['label_for'] ]; } ?>" /> 
	<?php
 
}

function dealia_field_password( $args ) {
	$options = get_option( 'dealia_options' );
	?>
    <input type="password" autocomplete="new-password" autofill="off"  name="dealia_options[<?php echo esc_attr( $args['label_for'] ); ?>]" value="<?php if($options && $options[ $args['label_for'] ]) { echo  $options[ $args['label_for'] ]; } ?>" /> 
    <?php
}

function dealia_options_page() {
    add_menu_page(
        'Dealia',
        'Dealia Connector',
        'manage_options',
        'dealia',
        'dealia_options_page_html',
        'data:image/svg+xml;base64,' . base64_encode('<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" x="0" y="0" viewBox="0 0 438.42 531.04" style="enable-background:new 0 0 438.42 531.04" xml:space="preserve"><style>.st1{fill:#662d91}.st3{fill:#f755ff}</style><path d="M372.61 185.96v12.11c.06-1.96.09-3.99.09-5.98 0-2.05-.03-4.11-.09-6.13z"/><path d="M365.93 139.72H308c-6.74 0-13.29.09-19.7.34-.91-3.09-1.9-6.14-2.99-9.13-.45-1.33-.94-2.6-1.45-3.9-7.86-20.15-18.89-37.53-33.03-52.09C236.66 60.4 219.8 49.07 200.22 41c-19.58-8.06-40.98-12.08-64.18-12.08H67.75V0h62.67C170.55 0 205.08 3.75 234 11.21c19.25 4.96 36.35 11.94 51.31 20.94 7.55 4.5 14.53 9.52 21 15.05 22.03 18.88 38.59 40.55 49.71 64.94 4.05 8.91 7.37 18.1 9.91 27.58z" style="fill:#ff962a"/><path class="st1" d="M74.21 391.28h-6.47v-28.62h.15c1.43 9.8 3.54 19.31 6.32 28.62z"/><path class="st1" d="M67.75 361.49v1.18h-1.93v-24.84c.2 8.03.84 15.92 1.93 23.66z"/><path class="st1" d="M65.81 325.68c-.06 2.05-.09 4.11-.09 6.16 0 1.99.03 3.99.09 5.98v24.84h1.93v28.62h-3.02V0h3.02v28.92h-1.93v296.76z"/><path class="st1" d="M67.75 28.92V302.5c-1.09 7.56-1.73 15.29-1.94 23.18V28.92h1.94zM0 0h64.73v391.28H0z"/><linearGradient id="SVGID_1_" gradientUnits="userSpaceOnUse" x1="144.44" y1="279.945" x2="372.61" y2="279.945"><stop offset="0" style="stop-color:#662d91"/><stop offset=".999" style="stop-color:#f015ff"/></linearGradient><path d="M372.61 185.96v12.11c-.4 15.04-2.3 29.56-5.71 43.59-2.33 9.59-5.36 18.94-9.1 28.06-9.94 24.17-24.51 45.29-43.69 63.27-19.16 18.01-42.88 32.21-71.1 42.64-27.14 10.06-58.08 15.23-92.77 15.62-2.63-9.03-4.53-18.64-5.8-28.8 18.82-.81 36.68-4.41 53.57-10.72 19.46-7.25 36.44-18.1 50.89-32.46 14.47-14.35 25.86-32 34.23-52.97 8.37-20.94 12.54-45.17 12.54-72.73 0-8.52-.48-16.74-1.48-24.75 2.69-.12 5.44-.18 8.19-.18h69.05c.63 5.65 1.03 11.42 1.18 17.32z" style="fill:url(#SVGID_1_)"/><path d="M372.61 185.96v12.11c.06-1.96.09-3.99.09-5.98 0-2.05-.03-4.11-.09-6.13z"/><path class="st1" d="M65.81 325.68v12.15c-.06-1.99-.09-3.99-.09-5.98 0-2.06.03-4.12.09-6.17z"/><path class="st3" d="M372.94 139.72v391.32h-80.59c-36.38 0-68.71-5.23-96.94-15.66-28.22-10.42-51.94-24.62-71.13-42.63-19.15-18.01-33.72-39.1-43.66-63.31-2.45-5.95-4.56-12.02-6.41-18.16h71.86c1.39 0 2.81 0 4.17-.03a150.7 150.7 0 0 0 5.05 14.81c8.37 20.94 19.76 38.61 34.23 52.97 14.45 14.35 31.43 25.17 50.89 32.45 19.49 7.28 40.25 10.91 62.27 10.91h69.93V198.07c.06-1.96.09-3.99.09-5.98 0-2.05-.03-4.11-.09-6.13v-17.32h-1.18c-.97-8.64-2.47-17.06-4.53-25.24-.31-1.23-.63-2.46-.97-3.68h7.01z"/><path class="st3" d="M150.24 391.25c-1.36.03-2.78.03-4.17.03H74.21c-2.78-9.31-4.9-18.83-6.32-28.62h67.84c2.93 0 5.83-.06 8.7-.21 1.28 10.16 3.18 19.77 5.81 28.8zM371.43 168.64h-69.05c-2.75 0-5.5.06-8.19.18-1.18-9.97-3.14-19.58-5.89-28.77 6.41-.24 12.96-.33 19.7-.33h57.93c2.57 9.34 4.38 18.98 5.5 28.92z"/><path class="st3" d="M294.19 168.82c-20.06.85-38.73 4.84-55.99 11.94-19.58 8.07-36.44 19.37-50.61 33.93-14.17 14.57-25.17 31.91-33.06 52.07-7.86 20.18-11.78 42.36-11.78 66.56 0 10.19.57 19.89 1.69 29.13-2.87.16-5.77.22-8.7.22H67.9c-.06-.4-.12-.79-.15-1.18V302.5c2.5-17.85 7.4-34.72 14.65-50.64 11.12-24.39 27.68-46.02 49.71-64.91 19.28-16.53 43.39-28.52 72.31-36.02 24.08-6.22 52.03-9.85 83.88-10.87 2.75 9.18 4.72 18.79 5.89 28.76zM67.75 302.5v58.98c-1.09-7.74-1.72-15.62-1.93-23.66v-12.15c.2-7.88.84-15.61 1.93-23.17z"/><path style="fill:#3500d4" d="M366.9 139.72h71.52v391.32H366.9z"/></svg>'),
        20
    );
}

add_action( 'admin_menu', 'dealia_options_page' );

function dealia_options_page_html() {

	


    try {
        $dealiaOptions = get_option( 'dealia_options' );
        if(is_array($dealiaOptions) && array_key_exists('dealia_field_email', $dealiaOptions) && strlen($dealiaOptions['dealia_field_email']) > 0) {
            $dealiaConnector = DealiaConnector::connect($dealiaOptions['dealia_field_email'], $dealiaOptions['dealia_field_password']);
        }

    } catch (Exception $e) { }    

	if ( ! current_user_can( 'manage_options' ) ) {
		return;
	}


    $settingErrors = get_settings_errors();

	if ( isset( $_GET['settings-updated'] ) ) {
        if(count($settingErrors) == 0 || $settingErrors[0]['type'] != 'error') {
    		add_settings_error( 'dealia_options', 'dealia_message', __( 'The account has been successfully connected', 'dealia' ), 'updated' );
        }
	}


	settings_errors( 'dealia_options' );
	?>


    <div class="dealiaintro"> 
        <div>
            <img class="dealiaicon" src="<?php echo  plugin_dir_url(__FILE__) . 'images/dealiaicon.png'; ?>">
        </div>
        Dealia is a quote management platform that allows to receive quote requests directly from your website, negotiate prices, make stress-free deals and get paid all in one place. It operates as a SAAS platform and is compatible with any website. Add <b class="dealiahighlight">Request a Quote</b> button to any content page or product page and <b class="dealiahighlight">Receive Quote Requests</b> (multi-item quotes and single-item quotes). <b class="dealiahighlight">Create Unlimited Forms</b> and assign them anywhere on your website.
    </div>


	<div class="wrap dealiaformwrap">
		<form action="options.php" method="post" autocomplete="off" autofill="off">
			<?php
			// output security fields for the registered setting "dealia"
			settings_fields( 'dealia' );
			// output setting sections and their fields
			// (sections are registered for "dealia", each field is registered to a specific section)
			do_settings_sections( 'dealia' );
			// output save settings button
			submit_button( DealiaConnector::$accessToken ? 'Update Dealia Account' : 'Connect Dealia Account' );
			?>            
		</form>
	</div>

    <div class="dealiaintro"> <div><img class="dealiaicon" src="<?php echo  plugin_dir_url(__FILE__) . 'images/dealiaicon.png'; ?>"></div> 
	<h2>Get started with Dealia! </h2>
	<div style="display:flex; max-width:100%; flex-wrap: wrap;">
		<div class="daSteps">
	<p style="padding: 1rem;"><span class="daNum">1</span> <b> <a class="dealiahighlight" href="https://dealia.com/register" target="_blank">Register an account </a> </b> with Dealia.com and then verify it by clicking the verification link in the email you receive from Dealia.  </p>
</div>
	<div class="daSteps">
		<p style="padding: 1rem;"><span class="daNum">2</span> In WordPress, go to the <b> Settings => Permalinks</b>. In the <b>"Permalink structure"</b> section, choose any option other than "Plain". The application won't work with the "Plain" permalink structure. </p>
		</div>
			<div class="daSteps">
		<p style="padding: 1rem;"><span class="daNum">3</span> Login above with the Dealia login details. It will connect your Wordpress website with Dealia.  </p>
		</div>
			<div class="daSteps">
			<p style="padding: 1rem;"><span class="daNum">4</span> Log in to your Dealia.com account. In the "Items" section please choose the "Wordpress" platform. You can assign forms to posts and pages from there. If you have "WooCommerce" installed you can choose the "WooCommerce" platform in the "Items" section and assign forms to products. </p>
			</div>
			
			
		</div>
                <p>All features offered by our platform are described in our <b> <a class="dealiahighlight" href="https://dealia.com/help/"  target="_blank">help center</a></b>.  </p>
				<p>Do you have any questions? Feel free to <b> <a class="dealiahighlight" href="https://dealia.com/contact"  target="_blank">contact us</a></b>.  </p>
			

    </div>

	<?php
}

function dealia_sanitize_options($data)
{
        $dealiaConnector = DealiaConnector::connect($data['dealia_field_email'], $data['dealia_field_password']);
        if(!$dealiaConnector) {
            // errors
            if(DealiaConnector::$attempts == 0) {   
                unset($data['dealia_field_email']);
                unset($data['dealia_field_password']);
                add_settings_error( 'dealia_options', 'error', 'Authentication failed. Invalid email address or password', 'error' );
                DealiaConnector::$attempts++;
            }
        }
        else {

            if(DealiaConnector::getAccessToken() == null) {
                if(DealiaConnector::$attempts == 0) {   
                    unset($data['dealia_field_email']);
                    unset($data['dealia_field_password']);
                    add_settings_error( 'dealia_options', 'error', 'Authentication failed. We have sent an email with a confirmation link to your email address. In order to complete the sign-up process, please click the confirmation link.', 'error' );
                    DealiaConnector::$attempts++;
                }
            }
            else {

                $integrationCodeUrl = $dealiaConnector->getIntegrationCodeURL();

                if($integrationCodeUrl) {
                    update_option('dealia_integration_code', $integrationCodeUrl);
                }

                $dealiaConnector->enableWordpressIntegration();

                $plugin_path = trailingslashit( WP_PLUGIN_DIR ) . 'woocommerce/woocommerce.php';

                if (in_array( $plugin_path, wp_get_active_and_valid_plugins() )) {
                    $dealiaConnector->enableWoocommerceIntegration();
                }
            }
        }  

        return $data;
}

function dealia_loadCss() {
    echo '<style> .dealiahighlight { color: #cc4b8d; } .dealiaicon { max-width: 40px; float: left; margin-right: 10px; }  .dealiaintro { padding-top: 30px; padding-bottom: 30px; background-color: #fff; padding-left: 15px; padding-right: 15px; margin-top: 10px; margin-right: 15px; } .dealiaformwrap { max-width: 800px;margin-left: auto;margin-right: auto;border: color;background-color: #fff;padding: 10px;padding-right: 20px;padding-left: 20px;border: 1px solid #ccc; } .daNum { margin-bottom: 10px; color: #fff;border-radius: 50%;width: 2em;height: 2em;background: #7022b7;text-align: center;display: flex;justify-content: center;align-items: center;box-sizing: border-box;margin-right: 8px;border: 3px solid #7c19df;} .daSteps { box-shadow: 0 3px 20px -10px rgba(179, 179, 179, 0.75); width: 25%; } @media screen and (max-width: 600px) { .daSteps {width: 50%;}} </style>';
	

}

function dealia_add_to_head() {
	if(array_key_exists('dealia', $_GET)) {	
		if(array_key_exists('type', $_GET) && $_GET['type'] == 'products') {
		    echo '<!-- Dealia code start';		
			add_filter( 'woocommerce_product_data_store_cpt_get_products_query', 'handle_custom_query_var', 10, 2 );
			function handle_custom_query_var( $query, $query_vars ) {
				if ( isset( $query_vars['like_name'] ) && ! empty( $query_vars['like_name'] ) ) {
					$query['s'] = esc_attr( $query_vars['like_name'] );
				}
				return $query;
			}			
			$paged = 1;
			if(array_key_exists('page', $_GET)) {
			$paged = $_GET['page'];
			}									
			$qparams = array(
				'status'            => array( 'draft', 'pending', 'private', 'publish' ),
				'type'              => array_merge( array_keys( wc_get_product_types() ) ),
				'parent'            => null,				
				'limit'             => 20,  // -1 for unlimited
				'offset'            => null,
				'page'              => $paged,
				'return'            => 'objects',
				'paginate'          => false,
				'shipping_class'    => array(),
			);						
			if(array_key_exists('phrase' ,$_GET) && $_GET['phrase'] != '*') {
				$qparams['like_name'] = $_GET['phrase'];
			}			
			$products = wc_get_products( $qparams );
			$dealiaOutput= [];
			$i = 0;			
			foreach( $products as $product ) {
				$imageUrl = '';
				$imageAttachemnt = wp_get_attachment_image_src( $product->get_image_id(), 'large' );
				if($imageAttachemnt) {
					$imageUrl = $imageAttachemnt[0];
				}				
				$dealiaOutput['a' . $i++] = array('external_url' => get_permalink($product->get_id()), 'image' => $imageUrl
, 'name' => $product->get_name());				
			}				
			echo json_encode($dealiaOutput);
			echo ' Dealia code end -->';
		}
		else {		
			echo '<!-- Dealia code start';
			$paged = 1;
			if(array_key_exists('page', $_GET)) {
			$paged = $_GET['page'];
			}
			$qparams = array('post_type' => array('page','post'), 'orderby' => 'title', 'order' => 'ASC', 'showposts' => 20, 'paged' => $paged);
			if(array_key_exists('phrase' ,$_GET) && $_GET['phrase'] != '*') {
				$qparams['s'] = $_GET['phrase'];
			}
			$daPosts =  get_posts($qparams);
			$dealiaOutput= [];
			$i = 0;
			foreach($daPosts as $daPost) {
				$daPostImg = wp_get_attachment_url( get_post_thumbnail_id($daPost->ID));
				if(!$daPostImg) { $daPostImg = ''; }
				$dealiaOutput['a' . $i++] = array('external_url' => get_permalink($daPost), 'image' => $daPostImg, 'name' => $daPost->post_title);
			}
			echo json_encode($dealiaOutput);
			echo ' Dealia code end -->';
		}
	}

    if(get_option('dealia_integration_code')) {
        echo '<style>html { opacity: 0; }</style><script async type="text/javascript" src="' . get_option('dealia_integration_code') . '"></script>';
    }
}

add_action( 'wp_head', 'dealia_add_to_head' );


if(array_key_exists('dealia', $_GET)) {
    try {
		if(function_exists('curl_version')) {
			$ch = curl_init();
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($ch, CURLOPT_URL, get_site_url());
			curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
			curl_setopt($ch, CURLOPT_HEADER, true);
			curl_setopt($ch, CURLOPT_NOBODY, true);					
			$response = curl_exec($ch);

			if(strpos($response, 'Access-Control-Allow-Origin') === FALSE) {
				header("Access-Control-Allow-Origin: *", true);
			}
		}
    } catch (Exception $e) { }    
}
