<?php
class DealiaConnector {
    const API_URL = 'https://jack.dealia.com';
    
    protected $companyId;
    public static $accessToken = null;
    public static $attempts = 0;
    public static $instance = null;

    public static function connect($email, $password) {

        $data = [
            'email' => $email ,
            'password' => $password,
        ];

        if(DealiaConnector::$instance != null) {
            return DealiaConnector::$instance;
        }

        DealiaConnector::$instance = new DealiaConnector();
        $response = DealiaConnector::$instance->request($data, '/core/users/login');
        if($response->code != 200) {
            return false;
        }
        DealiaConnector::$instance->companyId = str_replace('@', '', $response->data->user->company_id);
        DealiaConnector::$accessToken = $response->data->token;

        return DealiaConnector::$instance;
    }

    public function request($data, $action, $type = 'POST') {

        
        $ch = curl_init(self::API_URL . $action);
        if(DealiaConnector::$accessToken) {
        $authorization = "Authorization: Bearer " . DealiaConnector::$accessToken;
        curl_setopt($ch, CURLOPT_HTTPHEADER, array( $authorization ));
        }
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POST, 1);

        if($type == 'GET') {
            curl_setopt($ch, CURLOPT_POST, 0);
        }

        if($data) {
            curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
        }
        $response = curl_exec($ch);
    
        curl_close($ch);
    
        return json_decode($response);
    }

    public function getCompanyId() {
        return $this->companyId;
    }

    public function getIntegrationCodeURL() {
        return  self::API_URL . '/integrations/' . $this->getCompanyId() .  '/integration.js?v=20';
    }

    public static function getAccessToken() {
        return DealiaConnector::$accessToken;
    }

    public function enableWordpressIntegration() {
        $companySettings = $this->request(null, '/Catalog/Companies/get', 'GET');

        $customConfig = json_decode($companySettings->data->profile->config);
        
        if($customConfig->integrations) {
        $integrationsSettings = json_decode($customConfig->integrations);
        }
        else {
            $customConfig->integrations = new stdClass();
            $integrationsSettings = $customConfig->integrations;
        }

        $integrationSetting = new stdClass();
        $integrationSetting->url = $this->getSiteUrl();

        // integrating the wordpress plugin
        $integrationsSettings->wordpress = $integrationSetting;
        // setting the wordpress plugin as last used
        $integrationsSettings->last_used = 'wordpress';
        $customConfig->integrations = json_encode($integrationsSettings);

        
        $postData = [
            'config_data' => json_encode($customConfig)
        
        ];


        $result = $this->request($postData, '/Catalog/Companies/upgrade_profile', 'POST');

    }    

    public function enableWoocommerceIntegration() {
        $companySettings = $this->request(null, '/Catalog/Companies/get', 'GET');

        $customConfig = json_decode($companySettings->data->profile->config);
        
        if($customConfig->integrations) {
        $integrationsSettings = json_decode($customConfig->integrations);
        }
        else {
            $customConfig->integrations = new stdClass();
            $integrationsSettings = $customConfig->integrations;
        }

        $integrationSetting = new stdClass();
        $integrationSetting->url = $this->getSiteUrl();

        // integrating the wordpress plugin
        $integrationsSettings->woocommerce = $integrationSetting;
        // setting the wordpress plugin as last used
        $integrationsSettings->last_used = 'woocommerce';
        $customConfig->integrations = json_encode($integrationsSettings);

        
        $postData = [
            'config_data' => json_encode($customConfig)
        
        ];


        $result = $this->request($postData, '/Catalog/Companies/upgrade_profile', 'POST');
    }

    public function getSiteUrl() {
        $siteUrl = get_site_url();


        if(strpos($siteUrl, 'localhost') === 0) {
            $siteUrl = 'https://' . $siteUrl;
        }

        return $siteUrl;
    }

}
?>